==> eam-wshub-proxyclient-11.4-8-sources.jar: net/datastream/schemas/mp_results/mp7006_001/MP7006_DeletePMScheduleEquipment_001_Result.java <==

package net.datastream.schemas.mp_results.mp7006_001;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_fields.PMSCHEDULEEQUIPMENTID;


/**
 * <p>Classe Java pour anonymous complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element name="ResultData">
 *           &lt;complexType>
 *             &lt;complexContent>
 *               &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *                 &lt;sequence>
 *                   &lt;element ref="{http://schemas.datastream.net/MP_fields}PMSCHEDULEEQUIPMENTID"/>
 *                 &lt;/sequence>
 *               &lt;/restriction>
 *             &lt;/complexContent>
 *           &lt;/complexType>
 *         &lt;/element>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "resultData"
})
@XmlRootElement(name = "MP7006_DeletePMScheduleEquipment_001_Result")
public class MP7006_DeletePMScheduleEquipment_001_Result {

    @XmlElement(name = "ResultData", required = true)
    protected MP7006_DeletePMScheduleEquipment_001_Result.ResultData resultData;

    /**
     * Obtient la valeur de la propriété resultData.
     * 
     * @return
     *     possible object is
     *     {@link MP7006_DeletePMScheduleEquipment_001_Result.ResultData }
     *     
     */
    public MP7006_DeletePMScheduleEquipment_001_Result.ResultData getResultData() {
        return resultData;
    }

    /**
     * Définit la valeur de la propriété resultData.
     * 
     * @param value
     *     allowed object is
     *     {@link MP7006_DeletePMScheduleEquipment_001_Result.ResultData }
     *     
     */
    public void setResultData(MP7006_DeletePMScheduleEquipment_001_Result.ResultData value) {
        this.resultData = value;
    }


    /**
     * <p>Classe Java pour anonymous complex type.
     * 
     * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
     * 
     * <pre>
     * &lt;complexType>
     *   &lt;complexContent>
     *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
     *       &lt;sequence>
     *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PMSCHEDULEEQUIPMENTID"/>
     *       &lt;/sequence>
     *     &lt;/restriction>
     *   &lt;/complexContent>
     * &lt;/complexType>
     * </pre>
     * 
     * 
     */
    @XmlAccessorType(XmlAccessType.FIELD)
    @XmlType(name = "", propOrder = {
        "pmscheduleequipmentid"
    })
    public static class ResultData {

        @XmlElement(name = "PMSCHEDULEEQUIPMENTID", namespace = "http://schemas.datastream.net/MP_fields", required = true)
        protected PMSCHEDULEEQUIPMENTID pmscheduleequipmentid;

        /**
         * Obtient la valeur de la propriété pmscheduleequipmentid.
         * 
         * @return
         *     possible object is
         *     {@link PMSCHEDULEEQUIPMENTID }
         *     
         */
        public PMSCHEDULEEQUIPMENTID getPMSCHEDULEEQUIPMENTID() {
            return pmscheduleequipmentid;
        }

        /**
         * Définit la valeur de la propriété pmscheduleequipmentid.
         * 
         * @param value
         *     allowed object is
         *     {@link PMSCHEDULEEQUIPMENTID }
         *     
         */
        public void setPMSCHEDULEEQUIPMENTID(PMSCHEDULEEQUIPMENTID value) {
            this.pmscheduleequipmentid = value;
        }

    }

}

==> eam-wshub-proxyclient-11.7-3-sources.jar: net/datastream/schemas/mp_results/mp7006_001/MP7006_DeletePMScheduleEquipment_001_Result.java <==

package net.datastream.schemas.mp_results.mp7006_001;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_fields.PMSCHEDULEEQUIPMENTID;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element name="ResultData">
 *           &lt;complexType>
 *             &lt;complexContent>
 *               &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *                 &lt;sequence>
 *                   &lt;element ref="{http://schemas.datastream.net/MP_fields}PMSCHEDULEEQUIPMENTID"/>
 *                 &lt;/sequence>
 *               &lt;/restriction>
 *             &lt;/complexContent>
 *           &lt;/complexType>
 *         &lt;/element>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "resultData"
})
@XmlRootElement(name = "MP7006_DeletePMScheduleEquipment_001_Result")
public class MP7006_DeletePMScheduleEquipment_001_Result {

    @XmlElement(name = "ResultData", required = true)
    protected MP7006_DeletePMScheduleEquipment_001_Result.ResultData resultData;

    /**
     * Gets the value of the resultData property.
     * 
     * @return
     *     possible object is
     *     {@link MP7006_DeletePMScheduleEquipment_001_Result.ResultData }
     *     
     */
    public MP7006_DeletePMScheduleEquipment_001_Result.ResultData getResultData() {
        return resultData;
    }

    /**
     * Sets the value of the resultData property.
     * 
     * @param value
     *     allowed object is
     *     {@link MP7006_DeletePMScheduleEquipment_001_Result.ResultData }
     *     
     */
    public void setResultData(MP7006_DeletePMScheduleEquipment_001_Result.ResultData value) {
        this.resultData = value;
    }


    /**
     * <p>Java class for anonymous complex type.
     * 
     * <p>The following schema fragment specifies the expected content contained within this class.
     * 
     * <pre>
     * &lt;complexType>
     *   &lt;complexContent>
     *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
     *       &lt;sequence>
     *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PMSCHEDULEEQUIPMENTID"/>
     *       &lt;/sequence>
     *     &lt;/restriction>
     *   &lt;/complexContent>
     * &lt;/complexType>
     * </pre>
     * 
     * 
     */
    @XmlAccessorType(XmlAccessType.FIELD)
    @XmlType(name = "", propOrder = {
        "pmscheduleequipmentid"
    })
    public static class ResultData {

        @XmlElement(name = "PMSCHEDULEEQUIPMENTID", namespace = "http://schemas.datastream.net/MP_fields", required = true)
        protected PMSCHEDULEEQUIPMENTID pmscheduleequipmentid;

        /**
         * Gets the value of the pmscheduleequipmentid property.
         * 
         * @return
         *     possible object is
         *     {@link PMSCHEDULEEQUIPMENTID }
         *     
         */
        public PMSCHEDULEEQUIPMENTID getPMSCHEDULEEQUIPMENTID() {
            return pmscheduleequipmentid;
        }

        /**
         * Sets the value of the pmscheduleequipmentid property.
         * 
         * @param value
         *     allowed object is
         *     {@link PMSCHEDULEEQUIPMENTID }
         *     
         */
        public void setPMSCHEDULEEQUIPMENTID(PMSCHEDULEEQUIPMENTID value) {
            this.pmscheduleequipmentid = value;
        }

    }

}
